pm_options_version_t

Enum pm_options_version_t 

#[non_exhaustive]
#[repr(u32)]
pub enum pm_options_version_t { PM_OPTIONS_VERSION_UNSET = 0, PM_OPTIONS_VERSION_CRUBY_3_3 = 1, PM_OPTIONS_VERSION_CRUBY_3_4 = 2, PM_OPTIONS_VERSION_CRUBY_3_5 = 3, PM_OPTIONS_VERSION_CRUBY_4_1 = 4, }
The version of Ruby syntax that we should be parsing with. This is used to allow consumers to specify which behavior they want in case they need to parse in the same way as a specific version of CRuby would have.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


PM_OPTIONS_VERSION_UNSET = 0

If an explicit version is not provided, the current version of prism will be used.



PM_OPTIONS_VERSION_CRUBY_3_3 = 1

The vendored version of prism in CRuby 3.3.x.



PM_OPTIONS_VERSION_CRUBY_3_4 = 2

The vendored version of prism in CRuby 3.4.x.



PM_OPTIONS_VERSION_CRUBY_3_5 = 3

The vendored version of prism in CRuby 4.0.x.



PM_OPTIONS_VERSION_CRUBY_4_1 = 4

The vendored version of prism in CRuby 4.1.x.

Implementations

Source

impl pm_options_version_t

pub const PM_OPTIONS_VERSION_CRUBY_4_0: pm_options_version_t = pm_options_version_t::PM_OPTIONS_VERSION_CRUBY_3_5

Source

impl pm_options_version_t

pub const PM_OPTIONS_VERSION_LATEST: pm_options_version_t = pm_options_version_t::PM_OPTIONS_VERSION_CRUBY_4_1