pub unsafe extern "C" fn pm_arena_free(arena: *mut pm_arena_t)Expand description
Frees both the held memory and the arena itself.
@param arena The arena to free.
pub unsafe extern "C" fn pm_arena_free(arena: *mut pm_arena_t)Frees both the held memory and the arena itself.
@param arena The arena to free.