pm_arena_new

Function pm_arena_new 

pub unsafe extern "C" fn pm_arena_new() -> *mut pm_arena_t
Returns a newly allocated and initialized arena. If the arena cannot be allocated, this function aborts the process.

@returns A pointer to the newly allocated arena. It is the responsibility of the caller to free the arena using pm_arena_free when it is no longer needed.