pub unsafe extern "C" fn pm_constant_length(
constant: *const pm_constant_t,
) -> usizeExpand description
Return the length of a constant.
@param constant The constant to get the length of. @returns The length of the constant.
pub unsafe extern "C" fn pm_constant_length(
constant: *const pm_constant_t,
) -> usizeReturn the length of a constant.
@param constant The constant to get the length of. @returns The length of the constant.