pm_magic_comment_key

Function pm_magic_comment_key 

pub unsafe extern "C" fn pm_magic_comment_key(
    magic_comment: *const pm_magic_comment_t,
) -> pm_location_t
Returns the location of the key associated with the given magic comment.

@param magic_comment the magic comment whose key location we want to get @returns the location of the key associated with the given magic comment