pm_magic_comment_value

Function pm_magic_comment_value 

pub unsafe extern "C" fn pm_magic_comment_value(
    magic_comment: *const pm_magic_comment_t,
) -> pm_location_t
Returns the location of the value associated with the given magic comment.

@param magic_comment the magic comment whose value location we want to get @returns the location of the value associated with the given magic comment