pub unsafe extern "C" fn pm_options_encoding_set(
options: *mut pm_options_t,
encoding: *const c_char,
)Expand description
Set the encoding option on the given options struct.
@param options The options struct to set the encoding on. @param encoding The encoding to set.