pm_options_filepath_set

Function pm_options_filepath_set 

pub unsafe extern "C" fn pm_options_filepath_set(
    options: *mut pm_options_t,
    filepath: *const c_char,
)
Set the filepath option on the given options struct.

@param options The options struct to set the filepath on. @param filepath The filepath to set.