pub unsafe extern "C" fn pm_options_free(options: *mut pm_options_t)Expand description
Free both the held memory of the given options struct and the struct itself.
@param options The options struct to free.
pub unsafe extern "C" fn pm_options_free(options: *mut pm_options_t)Free both the held memory of the given options struct and the struct itself.
@param options The options struct to free.