pub unsafe extern "C" fn pm_options_frozen_string_literal_set(
options: *mut pm_options_t,
frozen_string_literal: bool,
)Expand description
Set the frozen string literal option on the given options struct.
@param options The options struct to set the frozen string literal value on. @param frozen_string_literal The frozen string literal value to set.