pm_options_line_set

Function pm_options_line_set 

pub unsafe extern "C" fn pm_options_line_set(
    options: *mut pm_options_t,
    line: i32,
)
Set the line option on the given options struct.

@param options The options struct to set the line on. @param line The line to set.