pub unsafe extern "C" fn pm_options_main_script_set(
options: *mut pm_options_t,
main_script: bool,
)Expand description
Set the main script option on the given options struct.
@param options The options struct to set the main script value on. @param main_script The main script value to set.