pm_options_new

Function pm_options_new 

pub unsafe extern "C" fn pm_options_new() -> *mut pm_options_t
Allocate a new options struct. If the options struct cannot be allocated, this function aborts the process.

@returns A new options struct with default values. It is the responsibility of the caller to free this struct using pm_options_free().