pub unsafe extern "C" fn pm_options_partial_script_set(
options: *mut pm_options_t,
partial_script: bool,
)Expand description
Set the partial script option on the given options struct.
@param options The options struct to set the partial script value on. @param partial_script The partial script value to set.