pm_options_scopes_init

Function pm_options_scopes_init 

pub unsafe extern "C" fn pm_options_scopes_init(
    options: *mut pm_options_t,
    scopes_count: usize,
) -> bool
Allocate and zero out the scopes array on the given options struct.

@param options The options struct to initialize the scopes array on. @param scopes_count The number of scopes to allocate. @returns Whether or not the scopes array was initialized successfully.