pm_parser_comments_each

Function pm_parser_comments_each 

pub unsafe extern "C" fn pm_parser_comments_each(
    parser: *const pm_parser_t,
    callback: pm_comment_callback_t,
    data: *mut c_void,
)
Iterates over the comments associated with the given parser and calls the given callback for each comment.

@param parser the parser whose comments we want to iterate over @param callback the callback function to call for each comment. This function will be passed a pointer to the comment and the data parameter passed to this function. @param data the data to pass to the callback function for each comment. This can be NULL if no data needs to be passed to the callback function.