pm_parser_constant

Function pm_parser_constant 

pub unsafe extern "C" fn pm_parser_constant(
    parser: *const pm_parser_t,
    constant_id: pm_constant_id_t,
) -> *const pm_constant_t
Returns a pointer to the constant at the given id in the constant pool associated with the given parser.

@param parser the parser whose constant pool we want to look up from @param constant_id the id of the constant to look up (1-based) @returns a pointer to the constant at the given id