pub unsafe extern "C" fn pm_parser_constants_each(
parser: *const pm_parser_t,
callback: pm_constant_callback_t,
data: *mut c_void,
)Expand description
Iterates over the constants in the constant pool associated with the given parser and calls the given callback for each constant.
@param parser the parser whose constants we want to iterate over @param callback the callback function to call for each constant. This function will be passed a pointer to the constant and the data parameter passed to this function. @param data the data to pass to the callback function for each constant. This can be NULL if no data needs to be passed to the callback function.