pm_parser_constants_size

Function pm_parser_constants_size 

pub unsafe extern "C" fn pm_parser_constants_size(
    parser: *const pm_parser_t,
) -> usize
Returns the number of constants in the constant pool associated with the given parser.

@param parser the parser whose constant pool constants we want to get the size of @returns the number of constants in the constant pool associated with the given parser