pm_parser_data_loc

Function pm_parser_data_loc 

pub unsafe extern "C" fn pm_parser_data_loc(
    parser: *const pm_parser_t,
) -> *const pm_location_t
Returns the location of the DATA section that is associated with the given parser.

@param parser the parser whose data location we want to get @returns the location of the DATA section that is associated with the given parser. If it is unset, then the length will be set to 0.