pm_parser_errors_size

Function pm_parser_errors_size 

pub unsafe extern "C" fn pm_parser_errors_size(
    parser: *const pm_parser_t,
) -> usize
Returns the number of errors associated with the given parser.

@param parser the parser whose errors we want to get the size of @returns the number of errors associated with the given parser