pub unsafe extern "C" fn pm_parser_free(parser: *mut pm_parser_t)Expand description
Free both the memory held by the given parser and the parser itself.
@param parser The parser to free.
pub unsafe extern "C" fn pm_parser_free(parser: *mut pm_parser_t)Free both the memory held by the given parser and the parser itself.
@param parser The parser to free.