pm_parser_start_line

Function pm_parser_start_line 

pub unsafe extern "C" fn pm_parser_start_line(
    parser: *const pm_parser_t,
) -> i32
Returns the line that the parser was considered to have started on.

@param parser the parser whose start line we want to get @returns the line that the parser was considered to have started on