pm_parser_warnings_each

Function pm_parser_warnings_each 

pub unsafe extern "C" fn pm_parser_warnings_each(
    parser: *const pm_parser_t,
    callback: pm_diagnostic_callback_t,
    data: *mut c_void,
)
Iterates over the warnings associated with the given parser and calls the given callback for each warning.

@param parser the parser whose warnings we want to iterate over @param callback the callback function to call for each warning. This function will be passed a pointer to the warning and the data parameter passed to this function. @param data the data to pass to the callback function for each warning. This can be NULL if no data needs to be passed to the callback function.