pub unsafe extern "C" fn pm_parser_warnings_size(
parser: *const pm_parser_t,
) -> usizeExpand description
Returns the number of warnings associated with the given parser.
@param parser the parser whose warnings we want to get the size of @returns the number of warnings associated with the given parser