Function ruby_prism_sys::pm_size_to_native
source · pub unsafe extern "C" fn pm_size_to_native(
size: pm_pack_size
) -> usizeExpand description
Prism abstracts sizes away from the native system - this converts an abstract size to a native size.
@param size The abstract size to convert. @return The native size.