#[repr(C)]pub struct pm_error_recovery_node {
pub base: pm_node_t,
pub unexpected: *mut pm_node,
}Expand description
ErrorRecoveryNode
Represents a node that is either missing or unexpected and results in a syntax error.
Type: ::PM_ERROR_RECOVERY_NODE
@extends pm_node_t
Fields
base: pm_node_tThe embedded base node.
unexpected: *mut pm_nodeErrorRecoveryNode#unexpected
The unexpected node that was found in the tree, if there was one.