#[repr(C)]pub struct pm_line_offset_list_t {
pub size: usize,
pub capacity: usize,
pub offsets: *mut u32,
}Expand description
A list of offsets of the start of lines in a string. The offsets are assumed to be sorted/inserted in ascending order.
Fields
size: usizeThe number of offsets in the list.
capacity: usizeThe capacity of the list that has been allocated.
offsets: *mut u32The list of offsets.