Type Alias ruby_prism_sys::pm_context_t

source ·
pub type pm_context_t = c_uint;
While parsing, we keep track of a stack of contexts. This is helpful for error recovery so that we can pop back to a previous context when we hit a token that is understood by a parent context but not by the current context.