pm_error_recovery_node_t

Type Alias pm_error_recovery_node_t 

pub type pm_error_recovery_node_t = pm_error_recovery_node;
ErrorRecoveryNode

Represents a node that is either missing or unexpected and results in a syntax error.

Type: ::PM_ERROR_RECOVERY_NODE

@extends pm_node_t

Aliased Type

#[repr(C)]
pub struct pm_error_recovery_node_t { pub base: pm_node, pub unexpected: *mut pm_node, }

Fields

base: pm_node

The embedded base node.

unexpected: *mut pm_node

ErrorRecoveryNode#unexpected

The unexpected node that was found in the tree, if there was one.