pm_global_variable_write_node_t

Type Alias pm_global_variable_write_node_t 

pub type pm_global_variable_write_node_t = pm_global_variable_write_node;
GlobalVariableWriteNode

Represents writing to a global variable.

 $foo = 1
 ^^^^^^^^

Type: ::PM_GLOBAL_VARIABLE_WRITE_NODE

@extends pm_node_t

Aliased Type

#[repr(C)]
pub struct pm_global_variable_write_node_t { pub base: pm_node, pub name: u32, pub name_loc: pm_location_t, pub value: *mut pm_node, pub operator_loc: pm_location_t, }

Fields

base: pm_node

The embedded base node.

name: u32

GlobalVariableWriteNode#name

The name of the global variable, which is a $ followed by an identifier. Alternatively, it can be one of the special global variables designated by a symbol.

 $foo = :bar  # name `:$foo`
 $_Test = 123 # name `:$_Test`
name_loc: pm_location_t

GlobalVariableWriteNode#name_loc

The Location of the global variable’s name.

 $foo = :bar
 ^^^^
value: *mut pm_node

GlobalVariableWriteNode#value

The value to write to the global variable. It can be any non-void expression.

 $foo = :bar
        ^^^^
 $-xyz = 123
         ^^^
operator_loc: pm_location_t

GlobalVariableWriteNode#operator_loc

The Location of the = operator.

 $foo = :bar
      ^