pub type pm_locals_t = pm_locals;Expand description
This is a set of local variables in a certain lexical context (method, class, module, etc.). We need to track how many times these variables are read in order to warn if they only get written.
Aliased Type
struct pm_locals_t {
pub size: u32,
pub capacity: u32,
pub locals: *mut pm_local_t,
}Fields
size: u32The number of local variables in the set.
capacity: u32The capacity of the local variables set.
locals: *mut pm_local_tThe nullable allocated memory for the local variables in the set.