pm_node_list_t

Type Alias pm_node_list_t 

pub type pm_node_list_t = pm_node_list;
A list of nodes in the source, most often used for lists of children.

Aliased Type

#[repr(C)]
pub struct pm_node_list_t { pub size: usize, pub capacity: usize, pub nodes: *mut *mut pm_node, }

Fields

size: usize

The number of nodes in the list.

capacity: usize

The capacity of the list that has been allocated.

nodes: *mut *mut pm_node

The nodes in the list.