pub unsafe extern "C" fn pm_constant_start(
constant: *const pm_constant_t,
) -> *const u8Expand description
Return a raw pointer to the start of a constant.
@param constant The constant to get the start of. @returns A raw pointer to the start of the constant.