pub unsafe extern "C" fn pm_diagnostic_error_level(
diagnostic: *const pm_diagnostic_t,
) -> pm_error_level_tExpand description
Get the error level associated with the given diagnostic.
@param diagnostic The diagnostic to get the error level of. @returns The error level of the given diagnostic. If the diagnostic was a warning, or is in any way not an error, then the return value is undefined and should not be relied upon.