pub unsafe extern "C" fn pm_diagnostic_type(
diagnostic: *const pm_diagnostic_t,
) -> *const c_charExpand description
Get the type of the given diagnostic.
@param diagnostic The diagnostic to get the type of. @returns The type of the given diagnostic. Note that this is a string representation of an internal ID, and is not meant to be relied upon as a stable identifier for the diagnostic. We do not guarantee that these will not change in the future. This is meant to be used for debugging and error reporting purposes, and not for programmatic checks.