pub unsafe extern "C" fn pm_diagnostic_warning_level(
diagnostic: *const pm_diagnostic_t,
) -> pm_warning_level_tExpand description
Get the warning level associated with the given diagnostic.
@param diagnostic The diagnostic to get the warning level of. @returns The warning level of the given diagnostic. If the diagnostic was an error, or is in any way not a warning, then the return value is undefined and should not be relied upon.