pub unsafe extern "C" fn pm_line_offset_list_line_column(
list: *const pm_line_offset_list_t,
cursor: u32,
start_line: i32,
) -> pm_line_column_tExpand description
Returns the line and column of the given offset. If the offset is not in the list, the line and column of the closest offset less than the given offset are returned.
@param list The list to search. @param cursor The offset to search for. @param start_line The line to start counting from. @returns The line and column of the given offset.