pub unsafe extern "C" fn pm_options_command_line_set(
options: *mut pm_options_t,
command_line: u8,
)Expand description
Sets the command line option on the given options struct.
@param options The options struct to set the command line option on. @param command_line The command_line value to set.