pub unsafe extern "C" fn pm_options_scope_forwarding_set(
scope: *mut pm_options_scope_t,
forwarding: u8,
)Expand description
Set the forwarding option on the given scope struct.
@param scope The scope struct to set the forwarding on. @param forwarding The forwarding value to set.