pub unsafe extern "C" fn pm_options_scope_init(
scope: *mut pm_options_scope_t,
locals_count: usize,
)Expand description
Create a new options scope struct. This will hold a set of locals that are in scope surrounding the code that is being parsed. If the scope was unable to allocate its locals, this function will abort the process.
@param scope The scope struct to initialize. @param locals_count The number of locals to allocate.