pub unsafe extern "C" fn pm_options_scope_mut(
options: *mut pm_options_t,
index: usize,
) -> *mut pm_options_scope_tExpand description
Return a mutable pointer to the scope at the given index within the given options.
@param options The options struct to get the scope from. @param index The index of the scope to get. @returns A mutable pointer to the scope at the given index.