pub unsafe extern "C" fn pm_options_version_set(
options: *mut pm_options_t,
version: *const c_char,
length: usize,
) -> boolExpand description
Set the version option on the given options struct by parsing the given string. If the string contains an invalid option, this returns false. Otherwise, it returns true.
@param options The options struct to set the version on. @param version The version to set. @param length The length of the version string. @returns Whether or not the version was parsed successfully.