pub unsafe extern "C" fn pm_parser_comments_size(
parser: *const pm_parser_t,
) -> usizeExpand description
Returns the number of comments associated with the given parser.
@param parser the parser whose comments we want to get the size of @returns the number of comments associated with the given parser