pub unsafe extern "C" fn pm_parser_errors_each(
parser: *const pm_parser_t,
callback: pm_diagnostic_callback_t,
data: *mut c_void,
)Expand description
Iterates over the errors associated with the given parser and calls the given callback for each error.
@param parser the parser whose errors we want to iterate over @param callback the callback function to call for each error. This function will be passed a pointer to the error and the data parameter passed to this function. @param data the data to pass to the callback function for each error. This can be NULL if no data needs to be passed to the callback function.