pub unsafe extern "C" fn pm_parser_frozen_string_literal(
parser: *const pm_parser_t,
) -> i8Expand description
Returns the frozen string literal value of the parser, as determined by the frozen_string_literal magic comment or the option set on the parser.
@param parser the parser whose frozen string literal value we want to get @returns -1 if disabled, 0 if unset, 1 if enabled