pub unsafe extern "C" fn pm_parser_line_offsets(
parser: *const pm_parser_t,
) -> *const pm_line_offset_list_tExpand description
Returns the line offsets that are associated with the given parser.
@param parser the parser whose line offsets we want to get @returns the line offsets that are associated with the given parser