pub unsafe extern "C" fn pm_parser_magic_comments_each(
parser: *const pm_parser_t,
callback: pm_magic_comment_callback_t,
data: *mut c_void,
)Expand description
Iterates over the magic comments associated with the given parser and calls the given callback for each magic comment.
@param parser the parser whose magic comments we want to iterate over @param callback the callback function to call for each magic comment. This function will be passed a pointer to the magic comment and the data parameter passed to this function. @param data the data to pass to the callback function for each magic comment. This can be NULL if no data needs to be passed to the callback function.