pub unsafe extern "C" fn pm_parser_start(
parser: *const pm_parser_t,
) -> *const u8Expand description
Returns the raw pointer to the start of the source that is being parsed.
@param parser the parser whose start pointer we want to get @returns the raw pointer to the start of the source that is being parsed