pub type pm_alias_global_variable_node_t = pm_alias_global_variable_node;Expand description
AliasGlobalVariableNode
Represents the use of the alias keyword to alias a global variable.
alias $foo $bar
^^^^^^^^^^^^^^^Type: ::PM_ALIAS_GLOBAL_VARIABLE_NODE
@extends pm_node_t
Aliased Type
#[repr(C)]pub struct pm_alias_global_variable_node_t {
pub base: pm_node,
pub new_name: *mut pm_node,
pub old_name: *mut pm_node,
pub keyword_loc: pm_location_t,
}Fields
base: pm_nodeThe embedded base node.
new_name: *mut pm_nodeAliasGlobalVariableNode#new_name
Represents the new name of the global variable that can be used after aliasing.
alias $foo $bar
^^^^old_name: *mut pm_nodeAliasGlobalVariableNode#old_name
Represents the old name of the global variable that can be used before aliasing.
alias $foo $bar
^^^^keyword_loc: pm_location_tAliasGlobalVariableNode#keyword_loc
The Location of the alias keyword.
alias $foo $bar
^^^^^