pub type pm_error_recovery_node_t = pm_error_recovery_node;Expand description
ErrorRecoveryNode
Represents a node that is either missing or unexpected and results in a syntax error.
Type: ::PM_ERROR_RECOVERY_NODE
@extends pm_node_t
Aliased Type
#[repr(C)]pub struct pm_error_recovery_node_t {
pub base: pm_node,
pub unexpected: *mut pm_node,
}Fields
base: pm_nodeThe embedded base node.
unexpected: *mut pm_nodeErrorRecoveryNode#unexpected
The unexpected node that was found in the tree, if there was one.