pub type pm_forwarding_super_node_t = pm_forwarding_super_node;Expand description
ForwardingSuperNode
Represents the use of the super keyword without parentheses or arguments, but which might have a block.
super
^^^^^ super { 123 }
^^^^^^^^^^^^^If it has any other arguments, it would be a SuperNode instead.
Type: ::PM_FORWARDING_SUPER_NODE
@extends pm_node_t
Aliased Type
#[repr(C)]pub struct pm_forwarding_super_node_t {
pub base: pm_node,
pub block: *mut pm_block_node,
}Fields
base: pm_nodeThe embedded base node.
block: *mut pm_block_nodeForwardingSuperNode#block
All other arguments are forwarded as normal, except the original block is replaced with the new block.