pub type pm_global_variable_read_node_t = pm_global_variable_read_node;Expand description
GlobalVariableReadNode
Represents referencing a global variable.
$foo
^^^^Type: ::PM_GLOBAL_VARIABLE_READ_NODE
@extends pm_node_t
Aliased Type
#[repr(C)]pub struct pm_global_variable_read_node_t {
pub base: pm_node,
pub name: u32,
}Fields
base: pm_nodeThe embedded base node.
name: u32GlobalVariableReadNode#name
The name of the global variable, which is a $ followed by an identifier. Alternatively, it can be one of the special global variables designated by a symbol.
$foo # name `:$foo` $_Test # name `:$_Test`