pub type pm_node_list_t = pm_node_list;Expand description
A list of nodes in the source, most often used for lists of children.
Aliased Type
#[repr(C)]pub struct pm_node_list_t {
pub size: usize,
pub capacity: usize,
pub nodes: *mut *mut pm_node,
}Fields
size: usizeThe number of nodes in the list.
capacity: usizeThe capacity of the list that has been allocated.
nodes: *mut *mut pm_nodeThe nodes in the list.